@@ -58,7 +58,7 @@
 #include <pilz_industrial_motion_planner_testutils/sequence.h>
 #include <pilz_industrial_motion_planner_testutils/xml_testdata_loader.h>
 
-#include "moveit_msgs/MoveGroupSequenceAction.h"
+#include <moveit_msgs/MoveGroupSequenceAction.h>
 
 static constexpr int WAIT_FOR_ACTION_SERVER_TIME_OUT{ 10 };  // seconds
 
@@ -393,9 +393,9 @@ TEST_F(IntegrationTestSequenceAction, TestActionServerCallbacks)
   }
 
   // send goal using mocked callback methods
-  ac_.sendGoal(seq_goal, std::bind(&IntegrationTestSequenceAction::done_callback, this, ph::_1, ph::_2),
-               std::bind(&IntegrationTestSequenceAction::active_callback, this),
-               std::bind(&IntegrationTestSequenceAction::feedback_callback, this, ph::_1));
+  ac_.sendGoal(
+      seq_goal, [this](const auto& state, const auto& result) { done_callback(state, result); },
+      [this] { active_callback(); }, [this](const auto& feedback) { feedback_callback(feedback); });
 
   // wait for the ecpected events
   BARRIER({ GOAL_SUCCEEDED_EVENT, SERVER_IDLE_EVENT });
