@@ -34,9 +34,9 @@
 
 #include <gtest/gtest.h>
 
-#include "pilz_industrial_motion_planner/joint_limits_extension.h"
+#include <pilz_industrial_motion_planner/joint_limits_extension.h>
 
-#include "pilz_industrial_motion_planner/joint_limits_validator.h"
+#include <pilz_industrial_motion_planner/joint_limits_validator.h>
 
 using namespace pilz_industrial_motion_planner;
 
