@@ -36,10 +36,10 @@
 
 #include <gtest/gtest.h>
 
-#include "pilz_industrial_motion_planner/joint_limits_aggregator.h"
-#include "pilz_industrial_motion_planner/trajectory_generator_lin.h"
-#include "pilz_industrial_motion_planner_testutils/command_types_typedef.h"
-#include "pilz_industrial_motion_planner_testutils/xml_testdata_loader.h"
+#include <pilz_industrial_motion_planner/joint_limits_aggregator.h>
+#include <pilz_industrial_motion_planner/trajectory_generator_lin.h>
+#include <pilz_industrial_motion_planner_testutils/command_types_typedef.h>
+#include <pilz_industrial_motion_planner_testutils/xml_testdata_loader.h>
 #include "test_utils.h"
 
 #include <moveit/kinematic_constraints/utils.h>
@@ -48,7 +48,7 @@
 #include <moveit/robot_state/conversions.h>
 #include <moveit/robot_state/robot_state.h>
 
-#include "rclcpp/rclcpp.hpp"
+#include <rclcpp/rclcpp.hpp>
 
 using namespace pilz_industrial_motion_planner;
 using namespace pilz_industrial_motion_planner_testutils;
@@ -88,8 +88,8 @@ protected:
     node_ = rclcpp::Node::make_shared("unittest_trajectory_generator_lin", node_options);
 
     // load robot model
-    robot_model_loader::RobotModelLoader rm_loader(node_);
-    robot_model_ = rm_loader.getModel();
+    rm_loader_ = std::make_unique<robot_model_loader::RobotModelLoader>(node_);
+    robot_model_ = rm_loader_->getModel();
     ASSERT_TRUE(bool(robot_model_)) << "Failed to load robot model";
     planning_scene_ = std::make_shared<planning_scene::PlanningScene>(robot_model_);
 
@@ -118,19 +118,26 @@ protected:
     pilz_industrial_motion_planner::JointLimitsContainer joint_limits =
         pilz_industrial_motion_planner::JointLimitsAggregator::getAggregatedLimits(
             node_, PARAM_NAMESPACE_LIMITS, robot_model_->getActiveJointModels());
-    CartesianLimit cart_limits;
-    cart_limits.setMaxRotationalVelocity(0.5 * M_PI);
-    cart_limits.setMaxTranslationalAcceleration(2);
-    cart_limits.setMaxTranslationalDeceleration(2);
-    cart_limits.setMaxTranslationalVelocity(1);
+
+    cartesian_limits::Params cart_limits;
+    cart_limits.max_rot_vel = 0.5 * M_PI;
+    cart_limits.max_trans_acc = 2;
+    cart_limits.max_trans_dec = 2;
+    cart_limits.max_trans_vel = 1;
+
     planner_limits_.setJointLimits(joint_limits);
     planner_limits_.setCartesianLimits(cart_limits);
 
     // initialize the LIN trajectory generator
-    lin_ = std::make_unique<TrajectoryGeneratorLIN>(robot_model_, planner_limits_);
+    lin_ = std::make_unique<TrajectoryGeneratorLIN>(robot_model_, planner_limits_, planning_group_);
     ASSERT_NE(nullptr, lin_) << "Failed to create LIN trajectory generator.";
   }
 
+  void TearDown() override
+  {
+    robot_model_.reset();
+  }
+
   bool checkLinResponse(const planning_interface::MotionPlanRequest& req,
                         const planning_interface::MotionPlanResponse& res)
   {
@@ -159,6 +166,7 @@ protected:
   // ros stuff
   rclcpp::Node::SharedPtr node_;
   moveit::core::RobotModelConstPtr robot_model_;
+  std::unique_ptr<robot_model_loader::RobotModelLoader> rm_loader_;
   planning_scene::PlanningSceneConstPtr planning_scene_;
 
   // lin trajectory generator using model without gripper
@@ -181,22 +189,22 @@ protected:
 TEST_F(TrajectoryGeneratorLINTest, TestExceptionErrorCodeMapping)
 {
   {
-    std::shared_ptr<LinTrajectoryConversionFailure> ltcf_ex{ new LinTrajectoryConversionFailure("") };
+    auto ltcf_ex = std::make_shared<LinTrajectoryConversionFailure>("");
     EXPECT_EQ(ltcf_ex->getErrorCode(), moveit_msgs::msg::MoveItErrorCodes::FAILURE);
   }
 
   {
-    std::shared_ptr<JointNumberMismatch> jnm_ex{ new JointNumberMismatch("") };
+    auto jnm_ex = std::make_shared<JointNumberMismatch>("");
     EXPECT_EQ(jnm_ex->getErrorCode(), moveit_msgs::msg::MoveItErrorCodes::INVALID_GOAL_CONSTRAINTS);
   }
 
   {
-    std::shared_ptr<LinJointMissingInStartState> ljmiss_ex{ new LinJointMissingInStartState("") };
+    auto ljmiss_ex = std::make_shared<LinJointMissingInStartState>("");
     EXPECT_EQ(ljmiss_ex->getErrorCode(), moveit_msgs::msg::MoveItErrorCodes::INVALID_ROBOT_STATE);
   }
 
   {
-    std::shared_ptr<LinInverseForGoalIncalculable> lifgi_ex{ new LinInverseForGoalIncalculable("") };
+    auto lifgi_ex = std::make_shared<LinInverseForGoalIncalculable>("");
     EXPECT_EQ(lifgi_ex->getErrorCode(), moveit_msgs::msg::MoveItErrorCodes::NO_IK_SOLUTION);
   }
 }
@@ -215,7 +223,7 @@ TEST_F(TrajectoryGeneratorLINTest, nonZeroStartVelocity)
   // try to generate the result
   planning_interface::MotionPlanResponse res;
   EXPECT_FALSE(lin_->generate(planning_scene_, req, res));
-  EXPECT_EQ(res.error_code_.val, moveit_msgs::msg::MoveItErrorCodes::INVALID_ROBOT_STATE);
+  EXPECT_EQ(res.error_code.val, moveit_msgs::msg::MoveItErrorCodes::INVALID_ROBOT_STATE);
 }
 
 /**
@@ -228,7 +236,7 @@ TEST_F(TrajectoryGeneratorLINTest, jointSpaceGoal)
   // generate the LIN trajectory
   planning_interface::MotionPlanResponse res;
   ASSERT_TRUE(lin_->generate(planning_scene_, lin_joint_req, res));
-  EXPECT_TRUE(res.error_code_.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
+  EXPECT_TRUE(res.error_code.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
 
   // check the resulted trajectory
   EXPECT_TRUE(checkLinResponse(lin_joint_req, res));
@@ -249,7 +257,7 @@ TEST_F(TrajectoryGeneratorLINTest, jointSpaceGoalNearZeroStartVelocity)
   // generate the LIN trajectory
   planning_interface::MotionPlanResponse res;
   ASSERT_TRUE(lin_->generate(planning_scene_, lin_joint_req, res));
-  EXPECT_TRUE(res.error_code_.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
+  EXPECT_TRUE(res.error_code.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
 
   // check the resulted trajectory
   EXPECT_TRUE(checkLinResponse(lin_joint_req, res));
@@ -266,7 +274,7 @@ TEST_F(TrajectoryGeneratorLINTest, cartesianSpaceGoal)
   // generate lin trajectory
   planning_interface::MotionPlanResponse res;
   ASSERT_TRUE(lin_->generate(planning_scene_, lin_cart_req, res));
-  EXPECT_TRUE(res.error_code_.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
+  EXPECT_TRUE(res.error_code.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
 
   // check the resulted trajectory
   EXPECT_TRUE(checkLinResponse(lin_cart_req, res));
@@ -290,15 +298,15 @@ TEST_F(TrajectoryGeneratorLINTest, cartesianTrapezoidProfile)
   /// +++++++++++++++++++++++
   planning_interface::MotionPlanResponse res;
   ASSERT_TRUE(lin_->generate(planning_scene_, lin_joint_req, res, 0.01));
-  EXPECT_EQ(res.error_code_.val, moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
+  EXPECT_EQ(res.error_code.val, moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
 
-  ASSERT_TRUE(testutils::checkCartesianTranslationalPath(res.trajectory_, target_link_hcd_));
+  ASSERT_TRUE(testutils::checkCartesianTranslationalPath(res.trajectory, target_link_hcd_));
 
   // check last point for vel=acc=0
-  for (size_t idx = 0; idx < res.trajectory_->getLastWayPointPtr()->getVariableCount(); ++idx)
+  for (size_t idx = 0; idx < res.trajectory->getLastWayPointPtr()->getVariableCount(); ++idx)
   {
-    EXPECT_NEAR(0.0, res.trajectory_->getLastWayPointPtr()->getVariableVelocity(idx), other_tolerance_);
-    EXPECT_NEAR(0.0, res.trajectory_->getLastWayPointPtr()->getVariableAcceleration(idx), other_tolerance_);
+    EXPECT_NEAR(0.0, res.trajectory->getLastWayPointPtr()->getVariableVelocity(idx), other_tolerance_);
+    EXPECT_NEAR(0.0, res.trajectory->getLastWayPointPtr()->getVariableAcceleration(idx), other_tolerance_);
   }
 }
 
@@ -375,29 +383,12 @@ TEST_F(TrajectoryGeneratorLINTest, LinStartEqualsGoal)
   // generate the LIN trajectory
   planning_interface::MotionPlanResponse res;
   ASSERT_TRUE(lin_->generate(planning_scene_, lin_joint_req, res));
-  EXPECT_TRUE(res.error_code_.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
+  EXPECT_TRUE(res.error_code.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
 
   // check the resulted trajectory
   EXPECT_TRUE(checkLinResponse(lin_joint_req, res));
 }
 
-/**
- * @brief Checks that constructor throws an exception if no limits are given.
- *
- * Test Sequence:
- *    1. Call Ctor without set limits.
- *
- * Expected Results:
- *    1. Ctor throws exception.
- */
-TEST_F(TrajectoryGeneratorLINTest, CtorNoLimits)
-{
-  pilz_industrial_motion_planner::LimitsContainer planner_limits;
-
-  EXPECT_THROW(pilz_industrial_motion_planner::TrajectoryGeneratorLIN(robot_model_, planner_limits),
-               pilz_industrial_motion_planner::TrajectoryGeneratorInvalidLimitsException);
-}
-
 /**
  * @brief Checks that generate() function returns 'false' if called with an
  * incorrect number of joints.
@@ -419,7 +410,7 @@ TEST_F(TrajectoryGeneratorLINTest, IncorrectJointNumber)
   // generate the LIN trajectory
   planning_interface::MotionPlanResponse res;
   ASSERT_FALSE(lin_->generate(planning_scene_, lin_joint_req, res));
-  EXPECT_TRUE(res.error_code_.val == moveit_msgs::msg::MoveItErrorCodes::INVALID_GOAL_CONSTRAINTS);
+  EXPECT_TRUE(res.error_code.val == moveit_msgs::msg::MoveItErrorCodes::INVALID_GOAL_CONSTRAINTS);
 }
 
 /**
@@ -437,7 +428,7 @@ TEST_F(TrajectoryGeneratorLINTest, cartGoalIncompleteStartState)
   // generate lin trajectory
   planning_interface::MotionPlanResponse res;
   EXPECT_FALSE(lin_->generate(planning_scene_, lin_cart_req, res));
-  EXPECT_EQ(res.error_code_.val, moveit_msgs::msg::MoveItErrorCodes::INVALID_ROBOT_STATE);
+  EXPECT_EQ(res.error_code.val, moveit_msgs::msg::MoveItErrorCodes::INVALID_ROBOT_STATE);
 }
 
 /**
@@ -455,7 +446,7 @@ TEST_F(TrajectoryGeneratorLINTest, cartGoalFrameIdBothConstraints)
   // generate lin trajectory
   planning_interface::MotionPlanResponse res;
   ASSERT_TRUE(lin_->generate(planning_scene_, lin_cart_req, res));
-  EXPECT_TRUE(res.error_code_.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
+  EXPECT_TRUE(res.error_code.val == moveit_msgs::msg::MoveItErrorCodes::SUCCESS);
 
   // check the resulted trajectory
   EXPECT_TRUE(checkLinResponse(lin_cart_req, res));
